PathSecretMapCleanerCycled

Struct PathSecretMapCleanerCycled 

#[non_exhaustive]
pub struct PathSecretMapCleanerCycled {
Show 18 fields pub id_entries: usize, pub id_entries_retired: usize, pub id_entries_active: usize, pub id_entries_active_utilization: f32, pub id_entries_utilization: f32, pub id_entries_initial_utilization: f32, pub address_entries: usize, pub address_entries_active: usize, pub address_entries_active_utilization: f32, pub address_entries_retired: usize, pub address_entries_utilization: f32, pub address_entries_initial_utilization: f32, pub id_entries_in_last_hs_period: usize, pub id_entries_in_last_hs_period_utilization: f32, pub handshake_requests: usize, pub handshake_requests_skipped: usize, pub handshake_lock_duration: Duration, pub duration: Duration,
}
Emitted when the cleaner task performed a single cycle

This can be used to track cache utilization

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id_entries: usize

The number of Path Secret ID entries left after the cleaning cycle

id_entries_retired: usize

The number of Path Secret ID entries that were retired in the cycle

id_entries_active: usize

Count of entries accessed since the last cycle

id_entries_active_utilization: f32

The utilization percentage of the active number of entries after the cycle

id_entries_utilization: f32

The utilization percentage of the available number of entries after the cycle

id_entries_initial_utilization: f32

The utilization percentage of the available number of entries before the cycle

address_entries: usize

The number of SocketAddress entries left after the cleaning cycle

address_entries_active: usize

Count of entries accessed since the last cycle

address_entries_active_utilization: f32

The utilization percentage of the active number of entries after the cycle

address_entries_retired: usize

The number of SocketAddress entries that were retired in the cycle

address_entries_utilization: f32

The utilization percentage of the available number of address entries after the cycle

address_entries_initial_utilization: f32

The utilization percentage of the available number of address entries before the cycle

id_entries_in_last_hs_period: usize

The number of Path Secret ID entries created within the last rehandshake period (usually 24 hours)

id_entries_in_last_hs_period_utilization: f32

The utilization percentage of Path Secret ID entries created within the last rehandshake period (usually 24 hours)

handshake_requests: usize

The number of handshake requests that are pending after the cleaning cycle

handshake_requests_skipped: usize

The number of handshake requests that were skipped in the cycle due to running out of time (other background handshakes took too long to complete, and so were postponed to the next cleaner cycle).

handshake_lock_duration: Duration

How long we kept the handshake lock held (this blocks completing handshakes).

duration: Duration

Total duration of a cycle.