#[non_exhaustive]pub struct StreamDecryptPacket {
pub decrypted_in_place: bool,
pub forced_copy: usize,
pub required_application_buffer: usize,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.decrypted_in_place: boolDid we decrypt the packet in place, or were we able to merge the copy and decrypt?
forced_copy: usizeThe number of bytes we were forced to copy after decrypting in the packet buffer.
This means that the application buffer was insufficiently large to allow us to directly copy as part of the decrypt. This can be non-zero even with decrypted_in_place=false, if we decrypted into the reassembly buffer. Right now it doesn’t take into account zero-copy reads from the reassembly buffer (e.g., with specialized Bytes).
required_application_buffer: usizeThe application buffer size that would avoid copies.