#[non_exhaustive]pub struct StreamMaxDataReceived {
pub increase: u64,
pub new_max_data: u64,
}Expand description
Indicates that the stream received additional flow control credits
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.increase: u64The number of bytes of flow control credits received
new_max_data: u64The new offset of the stream