#[non_exhaustive]pub struct StreamPacketTransmitted {
pub packet_len: usize,
pub payload_len: usize,
pub packet_number: u64,
pub stream_offset: u64,
pub is_fin: bool,
pub is_retransmission: bool,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.packet_len: usizeThe total size of the packet
payload_len: usizeThe size of the application data in the packet
packet_number: u64The packet number of the transmitted packet
stream_offset: u64The offset in the stream of the first byte in the packet
is_fin: boolWhether the packet contained the final bytes of the stream
is_retransmission: boolTrait Implementations
Sourceimpl Clone for StreamPacketTransmitted
impl Clone for StreamPacketTransmitted
Sourcefn clone(&self) -> StreamPacketTransmitted
fn clone(&self) -> StreamPacketTransmitted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamPacketTransmitted
impl Debug for StreamPacketTransmitted
Sourceimpl Event for StreamPacketTransmitted
impl Event for StreamPacketTransmitted