#[non_exhaustive]pub struct StreamWriteFlushed {
pub provided_len: usize,
pub committed_len: usize,
pub processing_duration: Duration,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.provided_len: usizeThe number of bytes that the application tried to write
committed_len: usizeThe amount that was written
processing_duration: DurationThe amount of time it took to process the write request
Note that this includes both any syscall and encryption overhead