#[non_exhaustive]pub struct StreamWriteShutdown {
pub buffer_len: usize,
pub background: bool,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.buffer_len: usizeThe number of bytes in the send buffer at the time of shutdown
background: boolIf the stream required a background task to drive the stream shutdown