pub struct SendOnly<T: Socket>(pub T);Tuple Fields
0: TTrait Implementations
Sourceimpl<T> Socket for SendOnly<T>where
T: Socket,
impl<T> Socket for SendOnly<T>where
T: Socket,
Sourcefn local_addr(&self) -> Result<SocketAddr>
fn local_addr(&self) -> Result<SocketAddr>
Returns the local address for the socket
fn protocol(&self) -> Protocol
Sourcefn features(&self) -> TransportFeatures
fn features(&self) -> TransportFeatures
Returns the
TransportFeatures that the socket supportsSourcefn poll_peek_len(&self, _cx: &mut Context<'_>) -> Poll<Result<usize>>
fn poll_peek_len(&self, _cx: &mut Context<'_>) -> Poll<Result<usize>>
Returns the amount of buffered data on the socket
Sourcefn poll_recv(
&self,
_cx: &mut Context<'_>,
_addr: &mut Addr,
_cmsg: &mut Receiver,
_buffer: &mut [IoSliceMut<'_>],
) -> Poll<Result<usize>>
fn poll_recv( &self, _cx: &mut Context<'_>, _addr: &mut Addr, _cmsg: &mut Receiver, _buffer: &mut [IoSliceMut<'_>], ) -> Poll<Result<usize>>
Receives data on the socket
Sourcefn try_send(
&self,
addr: &Addr,
ecn: ExplicitCongestionNotification,
buffer: &[IoSlice<'_>],
) -> Result<usize>
fn try_send( &self, addr: &Addr, ecn: ExplicitCongestionNotification, buffer: &[IoSlice<'_>], ) -> Result<usize>
Tries to send data on the socket, returning
Err(WouldBlock) if none could be sent.Sourcefn poll_send(
&self,
_cx: &mut Context<'_>,
addr: &Addr,
ecn: ExplicitCongestionNotification,
buffer: &[IoSlice<'_>],
) -> Poll<Result<usize>>
fn poll_send( &self, _cx: &mut Context<'_>, addr: &Addr, ecn: ExplicitCongestionNotification, buffer: &[IoSlice<'_>], ) -> Poll<Result<usize>>
Sends data on the socket
Sourcefn send_finish(&self) -> Result<()>
fn send_finish(&self) -> Result<()>
Shuts down the sender half of the socket, if a concept exists
Sourcefn local_port(&self) -> Result<u16>
fn local_port(&self) -> Result<u16>
Returns the local port for the socket
fn poll_recv_buffer( &self, cx: &mut Context<'_>, msg: &mut Message, ) -> Poll<Result<usize>>
fn try_send_buffer(&self, msg: &mut Message) -> Result<usize>
fn poll_send_buffer( &self, cx: &mut Context<'_>, msg: &mut Message, ) -> Poll<Result<usize>>